@@ -1,10 +1,10 @@
 
 progs <- if (WINDOWS) {
-           "rem.exe"
+           c("rem.exe", "asciicastclient.dll")
          } else {
-           "rem"
+           c("rem", "asciicastclient.so")
          }
 
 dest <- file.path(R_PACKAGE_DIR, paste0("bin", R_ARCH))
 dir.create(dest, recursive = TRUE, showWarnings = FALSE)
-file.copy(progs, dest, overwrite = TRUE)
+suppressWarnings(file.copy(progs, dest, overwrite = TRUE))
